# Slipper

This package fits 1d data with Penalised-splines using a Gibbs sampler.

This is a Python implementation of Patricio Maturana-Russel (@pmat747)'s P-spline fitting algorithm.
Check out the original [paper here](https://link.springer.com/article/10.1007/s00180-021-01066-7)
